python-timezones
----------------

![](https://github.com/Doist/python-timezones/workflows/Tests/badge.svg)

> [!IMPORTANT]
> This package is in low-priority maintenance mode. The Doist team will address
> bugs and security issues on a best-effort basis, but no new feature will be
> added.

A Python library that provides better selection of common timezones, with
optional HTML output.

Visit https://doist.github.io/python-timezones/ for more information.

Copyright: 2012-2024 by Doist

License: MIT.
